@@ -51,6 +51,7 @@ static int get_all_disks(PedDevice *discs[], int max_disks) {
 
 	while((direntry = readdir(devdir)) != NULL) {
 		char *fullname = NULL;
+		PedDevice *dev;
 
 		if(direntry->d_name[0] == '.')
 			continue;
@@ -63,8 +64,8 @@ static int get_all_disks(PedDevice *discs[], int max_disks) {
 		asprintf(&fullname, "%s/%s/%s", "/dev/discs",
 			direntry->d_name, "disc");
 
-		if ((discs[disk_count] = ped_device_get(fullname)))
-			disk_count++;
+		if ((dev = ped_device_get(fullname)) && !dev->read_only)
+			discs[disk_count++] = dev;
 		free(fullname);
 	}
 
@@ -125,8 +126,7 @@ static char *execute_fdisk(void) {
 	return(fdiskcmd);
 }
 
-static int handler (pid_t pid, void *user_data)
-{
+static int handler(pid_t pid, void *user_data) {
 	if ((dup2(DEBCONF_OLD_STDIN_FD, 0) == -1) ||
 	    (dup2(DEBCONF_OLD_STDOUT_FD, 1) == -1) ||
 	    (dup2(DEBCONF_OLD_STDOUT_FD, 2) == -1))
@@ -198,7 +198,7 @@ int main(int argc, char *argv[]) {
 		/* not properly handling characters in translations  */
 		debconf_get(debconf, "debian-installer/language");
 		language = extract_choice(debconf->value);
-		setenv("LANGUAGE", language, "1");
+		setenv("LANGUAGE", language, 1);
 
 		if (strcmp(disk,"false") != 0) {
 		  asprintf(&cmd, "/bin/sh %s %s", cmd_script, disk);
